@@ -23,6 +23,7 @@
 #include <config.h>
 #include <string.h>
 #include <stdlib.h>
+#include <ctype.h>
 #include <sys/types.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -60,11 +61,11 @@ typedef enum { INITIALISING, PAUSED, CONNECTING_TO_DAEMON, SYNCING, WAITING, NUM
 
 char *pixmaps[] = 
 {
-    "sync_broken.png",
-    "sync_paused.png",
-    "sync_icon.png",
-    "syncing_icon.png",
-    "sync_icon.png",
+    GNOME_ICONDIR "/sync_broken.png",
+    GNOME_ICONDIR "/sync_paused.png",
+    GNOME_ICONDIR "/sync_icon.png",
+    GNOME_ICONDIR "/syncing_icon.png",
+    GNOME_ICONDIR "/sync_icon.png",
 };
 
 
@@ -103,8 +104,6 @@ typedef struct {
 static void show_error_dialog (PilotApplet *self, gchar*,...);
 static void show_warning_dialog (PilotApplet *self, gchar*,...);
 static void show_message_dialog (PilotApplet *self, gchar*,...);
-static void pause_cb (PanelApplet *widget, gpointer data);
-static void resume_cb (PanelApplet *widget, gpointer data);
 static void cancel_cb (GtkButton* button, gpointer whatever);
 
 static void save_properties (PilotApplet *self);
@@ -113,27 +112,17 @@ static void load_properties (PilotApplet *self);
 static void pilot_draw (PilotApplet*);
 
 static void pilot_execute_program (PilotApplet*, const gchar *);
+static gchar *pick_pilot (PilotApplet *self);
+static void response_cb (GtkDialog *dialog, gint id, gpointer data);
+
+static gboolean timeout (PilotApplet *self);
+
 #define GPILOTD_DRUID "gpilotd-control-applet --druid"
 #define GPILOTD_CAPPLET "gpilotd-control-applet"
 #define CONDUIT_CAPPLET "gpilotd-control-applet --cap-id=1"
 
 /******************************************************************/
 
-static void
-gpilotd_set_style (GtkWidget *w)
-{
-	/*	GtkStyle *style; */
-	PangoFontDescription *pfd;
-
-	if (w == NULL) {
-		return;
-	}
-
-	pfd = pango_font_description_from_string ("monospace 8");
-	gtk_widget_modify_font (w, pfd);
-	pango_font_description_free (pfd);
-}
-
 static void 
 gpilotd_connect_cb (GnomePilotClient *client, 
 		    const gchar *id,
@@ -163,22 +152,9 @@ gpilotd_connect_cb (GnomePilotClient *client,
 		applet->overall_progress_bar = glade_xml_get_widget (xml,"overall_progress_bar");
 		applet->conduit_progress_bar = glade_xml_get_widget (xml,"conduit_progress_bar");
 		applet->cancel_button        = glade_xml_get_widget (xml,"cancel_button");
-/*
-		gpilotd_set_style (progressDialog);
-		gpilotd_set_style (glade_xml_get_widget (xml, "main_vbox"));
-		gpilotd_set_style (glade_xml_get_widget (xml, "action_area"));
-		gpilotd_set_style (glade_xml_get_widget (xml, "inner_vbox"));
-		gpilotd_set_style (glade_xml_get_widget (xml, "scrolled_window"));
-		gpilotd_set_style (glade_xml_get_widget (xml, "view_port"));
-		gpilotd_set_style (sync_label);
-		gpilotd_set_style (message_area);
-		gpilotd_set_style (overall_progress_bar);
-		gpilotd_set_style (conduit_progress_bar);
-		gpilotd_set_style (cancel_button);
-*/
 
 		gtk_signal_connect (GTK_OBJECT (applet->cancel_button),"clicked",
-				   GTK_SIGNAL_FUNC (cancel_cb),NULL);
+				   GTK_SIGNAL_FUNC (cancel_cb),applet);
 	} else {
 		gtk_text_buffer_place_cursor (applet->message_buffer,0);
 		gtk_text_buffer_set_text (applet->message_buffer, "", 0);
@@ -384,20 +360,24 @@ handle_client_error (PilotApplet *self)
 	}
 }
 
-void
+static void
 about_cb(BonoboUIComponent *uic, PilotApplet *pilot, const gchar *verbname)
 {
 	GtkWidget *about;
-	const gchar *authors[] = {"Vadim Strizhevsky, vadim@optonline.net"," Eskil Heyn Olsen, eskil@eskil.dk",NULL};
+	const gchar *authors[] = {"Vadim Strizhevsky <vadim@optonline.net>",
+				  "Eskil Heyn Olsen, <eskil@eskil.dk>",
+				  "JP Rosevear <jpr@ximian.com>", 
+				  "Chris Toshok <toshok@ximian.com>",
+				  "Frank Belew <frb@ximian.com>",
+				  NULL};
 
 	about = gnome_about_new (_("gnome-pilot applet"), 
 				 VERSION,
-				 _("Copyright \xc2\xa9 2000-2003 Free Software Foundation, Inc."),
-				 _("A dnd and gui monitor for gpilotd.\n"
-				   "Visit Website at http://eskil.org/gnome-pilot"),
+				 _("Copyright 2000-2003 Free Software Foundation, Inc."),
+				 _("A dnd and gui monitor for gpilotd.\n"),
 				 (const gchar**)authors,
 				 NULL,
-				 NULL,
+				 "Translations by the GNOME Translation Project",
 				 NULL /* pixbuf */);
 
 	gtk_window_set_wmclass (
@@ -461,24 +441,216 @@ properties_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname
 			    GTK_SIGNAL_FUNC (toggle_notices_cb),
 			    self);
 
-	gtk_signal_connect (GTK_OBJECT (dialog), "response",
-			    GTK_SIGNAL_FUNC (gtk_widget_hide),
-			    NULL);
+	g_signal_connect (GTK_OBJECT (dialog), "response",
+			  G_CALLBACK (response_cb),
+			  NULL);
 
 	gnome_window_icon_set_from_file (GTK_WINDOW (dialog), GNOME_ICONDIR "/sync_icon.png");
 
 	gtk_widget_show_all (dialog);
 }
 
-void
+static void
 help_cb(BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
-	/* FIXME */
+	PilotApplet *applet = user_data;
+	GError *error = NULL;
+
+	gnome_help_display_on_screen  ("gnome-pilot", "pilot-applet",
+				       (GTK_WIDGET (applet->applet)),
+				       &error);
+
+	if (error)
+	{
+		GtkWidget *message_dialog;
+		message_dialog = gtk_message_dialog_new (NULL, 0,
+							 GTK_MESSAGE_ERROR,
+							 GTK_BUTTONS_OK,
+							 _("There was an error displaying help: %s"),
+							 error->message);
+		g_error_free (error);
+		gtk_window_set_screen (GTK_WINDOW (message_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (applet)));
+		gtk_dialog_run (GTK_DIALOG (message_dialog));
+		gtk_widget_destroy (message_dialog);
+	}
+
 	return;
 }
 
-void
-state_cb(BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
+static void
+pref_help_cb(GtkDialog *dialog)
+{
+	GError *error = NULL;
+	gnome_help_display_on_screen  ("gnome-pilot", NULL /* FIXME Add section id later */,
+				       gtk_widget_get_screen (GTK_WIDGET (dialog)),
+				       &error);
+
+	if (error)
+	{
+		GtkWidget *message_dialog;
+		message_dialog = gtk_message_dialog_new (NULL, 0,
+							 GTK_MESSAGE_ERROR,
+							 GTK_BUTTONS_OK,
+							 _("There was an error displaying help: %s"),
+							 error->message);
+
+		g_error_free (error);
+		gtk_window_set_screen (GTK_WINDOW (message_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (dialog)));
+				       gtk_dialog_run (GTK_DIALOG (message_dialog));
+		gtk_widget_destroy (message_dialog);
+	}
+	return;
+}
+
+static void
+response_cb (GtkDialog *dialog, gint id, gpointer data)
+{
+
+	if (id == GTK_RESPONSE_HELP)
+	{
+		pref_help_cb (dialog);
+		return;
+	}
+
+	gtk_widget_hide (GTK_WIDGET (dialog));
+}
+
+
+static void
+complete_restore (GnomePilotClient* client, const gchar *id, 
+		  unsigned long handle, gpointer user_data)
+{	
+	PilotApplet *applet = user_data;
+
+	gtk_widget_destroy (applet->operationDialogWindow);
+}
+
+static void
+cancel_restore (PilotApplet *self, GnomeDialog *w,gpointer data)
+{
+	g_message (_("cancelling %d"),GPOINTER_TO_INT (data));
+	gnome_pilot_client_remove_request (self->gpc,GPOINTER_TO_INT (data));  
+}
+
+
+static void
+restore_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
+{
+	PilotApplet *applet = user_data;
+	int handle,i;
+	gchar *pilot_name;
+	gint pilot_id;
+	GladeXML *xml;
+	GtkWidget *dir_entry, *id_entry,*frame;
+	GtkWidget *device_menu, *menu_item,*menu;
+	GList *list;
+	gchar *buf;
+	restore_properties restore_props; 
+
+	
+	if (applet->curstate != WAITING) {
+		handle_client_error (applet);
+		return;
+	}
+	
+	if ((pilot_name=pick_pilot (applet)) == NULL) {
+		return;
+	}
+
+	if (gnome_pilot_client_get_pilot_base_dir_by_name (applet->gpc,pilot_name,&buf) == GPILOTD_OK) {
+		restore_props.backupdir = g_strdup_printf ("%s/backup/",buf);
+		g_free (buf);
+	} else {
+		handle_client_error (applet);
+		return;
+	}
+	if (gnome_pilot_client_get_pilot_id_by_name (applet->gpc,pilot_name,&pilot_id) != GPILOTD_OK) {
+		handle_client_error (applet);
+		return;
+	}
+
+	xml = glade_xml_new (applet->glade_file,"RestoreDialog",NULL);
+	applet->restoreDialog = glade_xml_get_widget (xml,"RestoreDialog");
+
+	dir_entry = glade_xml_get_widget (xml,"dir_entry");
+
+	gtk_entry_set_text (GTK_ENTRY (dir_entry),restore_props.backupdir);
+	g_free (restore_props.backupdir);
+	restore_props.backupdir=NULL;
+	/* FIXME: do we need to preserve the backupdir somewhere? */
+	
+	frame = glade_xml_get_widget (xml,"main_frame");
+	buf = g_strdup_printf (_("Restoring %s"), pilot_name);
+	gtk_frame_set_label (GTK_FRAME (frame), buf);
+	g_free (buf);
+	
+
+	id_entry =  glade_xml_get_widget (xml,"pilotid_entry");
+	
+	buf = g_strdup_printf ("%d",pilot_id);
+	gtk_entry_set_text (GTK_ENTRY (id_entry),buf);
+	g_free (buf);
+
+	applet->properties.cradles=NULL;
+	gnome_pilot_client_get_cradles (applet->gpc,&(applet->properties.cradles));
+	list = applet->properties.cradles;
+	
+	device_menu =  glade_xml_get_widget (xml,"device_menu");
+	menu =gtk_menu_new ();
+	
+	i=0;
+	while (list){
+		menu_item = gtk_menu_item_new_with_label ((gchar*)list->data);
+		gtk_widget_show (menu_item);
+/*
+		gtk_signal_connect (GTK_OBJECT (menu_item),"activate",
+				   GTK_SIGNAL_FUNC (activate_device),
+				   (gchar*)list->data);
+*/
+		gtk_menu_append (GTK_MENU (menu),menu_item);
+		list=list->next;
+		i++;
+	}
+	gtk_option_menu_set_menu (GTK_OPTION_MENU (device_menu),menu);	
+	if (i<=1) gtk_widget_set_sensitive (GTK_WIDGET (device_menu),FALSE);
+	else  gtk_widget_set_sensitive (GTK_WIDGET (device_menu),TRUE);
+	
+	if (gtk_dialog_run (GTK_DIALOG (applet->restoreDialog)) == GTK_RESPONSE_OK) {
+		int id;
+		
+		restore_props.backupdir = g_strdup(gtk_entry_get_text (GTK_ENTRY (dir_entry)));
+		gtk_widget_destroy (applet->restoreDialog);
+		if ( restore_props.backupdir == NULL || 
+		     strlen (restore_props.backupdir)==0) {
+			show_warning_dialog (applet, _("No directory to restore from."));
+			return;
+		}
+		
+		/* FIXME: how do we specify which device to restore on? */
+		id = gnome_pilot_client_connect__completed_request (applet->gpc, complete_restore, applet);
+		if (gnome_pilot_client_restore (applet->gpc,pilot_name,restore_props.backupdir,GNOME_Pilot_IMMEDIATE,0, &handle) == GPILOTD_OK) {
+			applet->operationDialogWindow = 
+				gnome_message_box_new (_("Press synchronize on the cradle to restore\n" 
+							 " or cancel the operation."),
+						       GNOME_MESSAGE_BOX_GENERIC,
+						       GNOME_STOCK_BUTTON_CANCEL,
+						       NULL);
+			gnome_dialog_button_connect (GNOME_DIALOG (applet->operationDialogWindow),0,
+						     (GCallback) cancel_restore ,GINT_TO_POINTER (handle));
+			gnome_dialog_run_and_close (GNOME_DIALOG (applet->operationDialogWindow));
+		} else {
+			show_warning_dialog (applet,_("Restore request failed"));
+		}
+		gtk_signal_disconnect (applet->gpc, id);		
+	} else {
+		gtk_widget_destroy (applet->restoreDialog);
+	}	
+}
+
+static void
+state_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
 	PilotApplet *applet = user_data;
 	GnomePilotClient *gpc = applet->gpc;
@@ -500,8 +672,48 @@ state_cb(BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 	return;
 }
 
+
+static void
+restart_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
+{
+	PilotApplet *applet = user_data;
+
+	if (applet->curstate == SYNCING) {
+		if ( gnome_dialog_run_and_close (GNOME_DIALOG (gnome_question_dialog (_("Pilot sync is currently in progress.\nAre you sure you want to restart daemon?"),NULL,NULL))) !=0 ) {
+			return;
+		}
+		if (applet->progressDialog!=NULL) {
+			gtk_widget_hide (applet->progressDialog);
+		}
+	}
+	applet->curstate = INITIALISING;
+	gnome_pilot_client_restart_daemon (applet->gpc);
+	gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET (applet->applet),
+			      _("Trying to connect to the GnomePilot Daemon"), NULL);
+	applet->timeout_handler_id = gtk_timeout_add (1000,(GtkFunction)timeout,applet);
+
+	return;
+}
+
+static void
+log_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
+{
+	PilotApplet *applet = user_data;
+	
+	if (applet->progressDialog != NULL) {
+		gtk_label_set_text (GTK_LABEL (applet->sync_label),"Last Sync Log");
+		gtk_widget_set_sensitive (applet->cancel_button,TRUE);
+		gtk_widget_show_all (applet->progressDialog);
+	} else {
+		show_message_dialog (applet, _("There's no last sync on record."));
+	}
+}
+
 static const BonoboUIVerb pilot_applet_menu_verbs [] = {
+	BONOBO_UI_VERB ("Restore", restore_cb),
 	BONOBO_UI_VERB ("State", state_cb),
+	BONOBO_UI_VERB ("Restart", restart_cb),
+	BONOBO_UI_VERB ("Log", log_cb),
 	BONOBO_UI_VERB ("Props", properties_cb),
 	BONOBO_UI_VERB ("Help", help_cb),
 	BONOBO_UI_UNSAFE_VERB ("About", about_cb),
@@ -515,9 +727,16 @@ install_popup_menu (PilotApplet *self, gboolean on_off)
 	char *menu_xml;
 	const char *menu_template = 
 		"<popup name=\"button3\">"
+		"<menuitem name=\"Restore\" verb=\"Restore\" _label=\"Restore...\""
+		"          pixtype=\"stock\" pixname=\"gtk-properties\"/>"
 		"<menuitem name=\"State\" verb=\"State\" _label=\"%s\""
 		"          pixtype=\"stock\" pixname=\"%s\"/>"
-		"<menuitem name=\"Props\" verb=\"Props\" _label=\"Properties...\""
+		"<menuitem name=\"Restart\" verb=\"Restart\" _label=\"Restart\""
+		"          pixtype=\"stock\" pixname=\"gtk-execute\"/>"
+		"<menuitem name=\"Log\" verb=\"Log\" _label=\"Last log...\""
+		"          pixtype=\"stock\" pixname=\"gtk-new\"/>"
+		"<separator/>"
+		"<menuitem name=\"Props\" verb=\"Props\" _label=\"Preferences...\""
 		"          pixtype=\"stock\" pixname=\"gtk-properties\"/>"
 		"<menuitem name=\"Item 2\" verb=\"Help\" _label=\"Help\""
 		"          pixtype=\"stock\" pixname=\"gtk-help\"/>"
@@ -724,6 +943,7 @@ timeout (PilotApplet *self)
 		break;
 	case SYNCING: 
 	case PAUSED:
+	default:
 		break;
 	}
 
@@ -812,12 +1032,6 @@ save_properties (PilotApplet *self)
 	/* gnome_config_set_int ("text_limit",properties.text_limit); */
 }
 
-static void cancel_restore (PilotApplet *self, GnomeDialog *w,gpointer data) {
-	g_message (_("cancelling %d"),GPOINTER_TO_INT (data));
-	gnome_pilot_client_remove_request (self->gpc,GPOINTER_TO_INT (data));  
-}
-
-
 static void
 activate_pilot_menu (PilotApplet *self, GtkMenuItem *widget, gpointer data)
 {
@@ -871,183 +1085,13 @@ pick_pilot (PilotApplet *self)
 	return pilot;
 }
 
-static void
-restore_dialog (PilotApplet *self, gpointer data)
-{
-	int handle,i;
-	gchar *pilot_name;
-	gint pilot_id;
-	GladeXML *xml;
-	GtkWidget *dir_entry, *id_entry,*frame;
-	GtkWidget *device_menu, *menu_item,*menu;
-	GList *list;
-	gchar *buf;
-	restore_properties restore_props; 
-
-	
-	if (self->curstate!=WAITING) {
-		handle_client_error (self);
-		return;
-	}
-	
-	if ((pilot_name=pick_pilot (self)) == NULL) {
-		return;
-	}
-
-	if (gnome_pilot_client_get_pilot_base_dir_by_name (self->gpc,pilot_name,&buf) == GPILOTD_OK) {
-		restore_props.backupdir = g_strdup_printf ("%s/backup/",buf);
-		g_free (buf);
-	} else {
-		handle_client_error (self);
-		return;
-	}
-	if (gnome_pilot_client_get_pilot_id_by_name (self->gpc,pilot_name,&pilot_id) != GPILOTD_OK) {
-		handle_client_error (self);
-		return;
-	}
-
-	xml = glade_xml_new (self->glade_file,"RestoreDialog",NULL);
-	self->restoreDialog = glade_xml_get_widget (xml,"RestoreDialog");
-
-	dir_entry = glade_xml_get_widget (xml,"dir_entry");
-
-	gtk_entry_set_text (GTK_ENTRY (dir_entry),restore_props.backupdir);
-	g_free (restore_props.backupdir);
-	restore_props.backupdir=NULL;
-	/* FIXME: do we need to preserve the backupdir somewhere? */
-	
-	frame = glade_xml_get_widget (xml,"main_frame");
-	buf = g_strdup_printf (_("Restoring %s"), pilot_name);
-	gtk_frame_set_label (GTK_FRAME (frame), buf);
-	g_free (buf);
-	
-
-	id_entry =  glade_xml_get_widget (xml,"pilotid_entry");
-	
-	buf = g_strdup_printf ("%d",pilot_id);
-	gtk_entry_set_text (GTK_ENTRY (id_entry),buf);
-	g_free (buf);
-
-	self->properties.cradles=NULL;
-	gnome_pilot_client_get_cradles (self->gpc,&(self->properties.cradles));
-	list = self->properties.cradles;
-	
-	device_menu =  glade_xml_get_widget (xml,"device_menu");
-	menu =gtk_menu_new ();
-	
-	i=0;
-	while (list){
-		menu_item = gtk_menu_item_new_with_label ((gchar*)list->data);
-		gtk_widget_show (menu_item);
-/*
-		gtk_signal_connect (GTK_OBJECT (menu_item),"activate",
-				   GTK_SIGNAL_FUNC (activate_device),
-				   (gchar*)list->data);
-*/
-		gtk_menu_append (GTK_MENU (menu),menu_item);
-		list=list->next;
-		i++;
-	}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (device_menu),menu);	
-	if (i<=1) gtk_widget_set_sensitive (GTK_WIDGET (device_menu),FALSE);
-	else  gtk_widget_set_sensitive (GTK_WIDGET (device_menu),TRUE);
-	
-	if (gnome_dialog_run_and_close (GNOME_DIALOG (self->restoreDialog))==0) {
-
-		restore_props.backupdir = g_strdup(gtk_entry_get_text (GTK_ENTRY (dir_entry)));
-		if ( restore_props.backupdir == NULL || 
-		     strlen (restore_props.backupdir)==0) {
-			show_warning_dialog (self, _("No directory to restore from."));
-			return;
-		}
-		
-		/* FIXME: how do we specify which device to restore on? */
-		if (gnome_pilot_client_restore (self->gpc,pilot_name,restore_props.backupdir,GNOME_Pilot_IMMEDIATE,0, &handle) == GPILOTD_OK) {
-			self->operationDialogWindow = 
-				gnome_message_box_new (_("Press synchronize on the cradle to restore\n" 
-							 " or cancel the operation."),
-						       GNOME_MESSAGE_BOX_GENERIC,
-						       GNOME_STOCK_BUTTON_CANCEL,
-						       NULL);
-			gnome_dialog_button_connect (GNOME_DIALOG (self->operationDialogWindow),0,
-						     (GCallback) cancel_restore ,GINT_TO_POINTER (handle));
-			gnome_dialog_run_and_close (GNOME_DIALOG (self->operationDialogWindow));
-		} else {
-			show_warning_dialog (self, _("Restore request failed"));
-		}
-	}
-}
-static void 
-properties_dialog (GtkWidget *w, gpointer data)
-{
-#ifdef FIXME
-	static GnomeHelpMenuEntry help_entry = {"gpilot-applet","properties"};
-
-	GtkWidget *button, *entry;
-	GladeXML *xml;
-
-	xml =glade_xml_new (self->glade_file,"PropertiesDialog");
-	pb=glade_xml_get_widget (xml,"PropertiesDialog");
-	
-	gtk_window_set_title (GTK_WINDOW (pb), _("GNOME PilotSync Properties"));
-
-
-	/* execute when clicked */
-
-	entry = glade_xml_get_widget (xml,"exec_entry");
-	gtk_entry_set_text (GTK_ENTRY (entry), properties.exec_when_clicked);
-	gtk_signal_connect_object (GTK_OBJECT (entry), "changed",
-				  GTK_SIGNAL_FUNC (gnome_property_box_changed),
-				  GTK_OBJECT (pb));
-	gtk_signal_connect (GTK_OBJECT (pb), "apply", 
-			   GTK_SIGNAL_FUNC (apply_exec_when_clicked_cb),entry);
-
-  
-	button = glade_xml_get_widget (xml,"notices_button");
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button),properties.popups);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			   GTK_SIGNAL_FUNC (toggle_notices_cb),
-			   NULL);
-
-
-/* 	gtk_signal_connect (GTK_OBJECT (pb),  */
-/* 			   "apply",  */
-/* 			   GTK_SIGNAL_FUNC (apply_properties_cb), */
-/* 			   NULL); */
-	gtk_signal_connect (GTK_OBJECT (pb),
-			   "destroy",
-			   GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			   pb);
-	gtk_signal_connect (GTK_OBJECT (pb),
-			   "help",
-			   GTK_SIGNAL_FUNC (gnome_help_pbox_display),
-			   &help_entry);
-
-	gtk_widget_show_all (pb);
-#endif
-	return;
-}
-
 static void
 pilot_execute_program (PilotApplet *self, const gchar *str)
 {
-	int err = -1;
-	int argc=0;
-	gchar **targv;
-	
 	g_return_if_fail (str != NULL);
 
-	targv=g_strsplit (str," ",0);
-	while (targv[argc]) argc++;
-	g_message ("pilot_execute_program (%s)",str);
-	err = gnome_execute_async (NULL,argc,targv);
-	if (err==-1) {
+	if (!g_spawn_command_line_async (str, NULL))
 		show_warning_dialog (self, _("Execution of %s failed"),str);
-	} else {
-		sleep (1);
-	}
-
-	g_strfreev (targv);
 }
 
 static gint 
@@ -1062,28 +1106,6 @@ pilot_clicked_cb (GtkWidget *widget,
 	return TRUE; 
 }
 
-static void
-pilot_link_dialog (PilotApplet *self, GtkWidget *widget, gpointer data)
-{
-	if (data==NULL) {
-		pilot_execute_program (self, GPILOTD_CAPPLET);
-	} else {
-		pilot_execute_program (self, CONDUIT_CAPPLET);
-	}
-}
-
-static void
-lastlog_dialog (PilotApplet *self, GtkWidget *widget, gpointer data)
-{
-	if (self->progressDialog != NULL) {
-		/* gtk_label_set_text (GTK_LABEL (sync_label),"Last Sync Log"); */
-		gtk_widget_set_sensitive (self->cancel_button,TRUE);
-		gtk_widget_show_all (self->progressDialog);
-	} else {
-		show_message_dialog (self, _("There's no last sync on record."));
-	}
-}
-
 static void 
 cancel_cb (GtkButton* button,gpointer applet)
 {
@@ -1104,6 +1126,66 @@ pilot_timeout (gpointer data)
 }
 */
 
+/* Copied from glib 2.6 so we can work with older GNOME's */
+static gchar **
+extract_uris (const gchar *uri_list)
+{
+	GSList *uris, *u;
+	const gchar *p, *q;
+	gchar **result;
+	gint n_uris = 0;
+
+	uris = NULL;
+
+	p = uri_list;
+
+	/* We don't actually try to validate the URI according to RFC
+	 * 2396, or even check for allowed characters - we just ignore
+	 * comments and trim whitespace off the ends.  We also
+	 * allow LF delimination as well as the specified CRLF.
+	 *
+	 * We do allow comments like specified in RFC 2483.
+	 */
+	while (p)
+	{
+		if (*p != '#')
+		{
+			while (g_ascii_isspace (*p))
+				p++;
+
+			q = p;
+			while (*q && (*q != '\n') && (*q != '\r'))
+				q++;
+
+			if (q > p)
+			{
+				q--;
+				while (q > p && g_ascii_isspace (*q))
+					q--;
+
+				if (q > p)
+				{
+					uris = g_slist_prepend (uris, g_strndup (p, q - p + 1));
+					n_uris++;
+				}
+			}
+		}
+		p = strchr (p, '\n');
+		if (p)
+			p++;
+	}
+
+	result = g_new (gchar *, n_uris + 1);
+
+	result[n_uris--] = NULL;
+	for (u = uris; u; u = u->next)
+		result[n_uris--] = u->data;
+
+	g_slist_free (uris);
+
+	return result;
+}
+
 static void
 dnd_drop_internal (GtkWidget        *widget,
 		   GdkDragContext   *context,
@@ -1117,7 +1199,6 @@ dnd_drop_internal (GtkWidget        *widget,
 	gchar *pilot_id;
 	gint  file_handle;
 	PilotApplet *self = PILOT_APPLET(data);
-
 	gchar **names;
 	int idx;
 
@@ -1126,28 +1207,22 @@ dnd_drop_internal (GtkWidget        *widget,
 	switch (info)
 	{
 	case TARGET_URI_LIST:
-		names = g_strsplit ((char *)selection_data->data, "\n", -1);
+		names = extract_uris (selection_data->data);
 		for (idx=0; names[idx]; idx++) {
-			char *ptr=names[idx];
-			while (iscntrl (ptr[strlen(ptr)-1])) {
-				ptr[strlen(ptr)-1] = 0;
-			}
-			if (ptr) {
-				/*
-				  if (strstr (file_type (ptr),"text")) {
-				  if (file_size (ptr)>properties.text_limit)
-				  g_message ("installing textfile as Doc (not implemented)");
+			/*
+			  if (strstr (file_type (ptr),"text")) {
+			  if (file_size (ptr)>properties.text_limit)
+			  g_message ("installing textfile as Doc (not implemented)");
 				  else
 				  g_message ("installing textfile as Memo (not implemented)");
 				  }
-				*/
-				g_message (_("installing \"%s\" to \"%s\""), ptr, pilot_id);
-				if (pilot_id) {
-					gnome_pilot_client_install_file (self->gpc,pilot_id,
-									ptr,
-									GNOME_Pilot_PERSISTENT,0,&file_handle);
-				} 
-			}
+			*/
+			g_message (_("installing \"%s\" to \"%s\""), names[idx], pilot_id);
+			if (pilot_id) {
+				gnome_pilot_client_install_file (self->gpc,pilot_id,
+								 names[idx],
+								 GNOME_Pilot_PERSISTENT,0,&file_handle);
+			} 
 		}
 		g_strfreev (names);
 		break;
@@ -1166,27 +1241,6 @@ applet_destroy (GtkWidget *applet, PilotApplet *self)
 	g_free (self);
 }
 
-static void
-restart_cb (PanelApplet *widget, gpointer data)
-{
-#ifdef FIXME
-	if ( curstate == SYNCING) {
-		if ( gnome_dialog_run_and_close (GNOME_DIALOG (gnome_question_dialog (_("Pilot sync is currently in progress.\nAre you sure you want to restart daemon?"),NULL,NULL))) !=0 ) {
-			return;
-		}
-		if (progressDialog!=NULL) {
-			gtk_widget_hide (progressDialog);
-		}
-	}
-	curstate = INITIALISING;
-	gnome_pilot_client_restart_daemon (gpc);
-	applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Trying to connect to "
-							  "the GnomePilot Daemon"));
-	timeout_handler_id = gtk_timeout_add (1000,timeout,pixmap);
-#endif
-	return;
-}
-
 static void
 create_pilot_widgets (GtkWidget *widget, PilotApplet *self) 
 { 
@@ -1235,46 +1289,10 @@ create_pilot_widgets (GtkWidget *widget, PilotApplet *self)
 	gtk_signal_connect (GTK_OBJECT (widget),"destroy", 
 			    GTK_SIGNAL_FUNC (applet_destroy),self); 
 
+	/* FIXME */
 	/* XXX change_orient */
 	/* XXX change_size */
-#if 0
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "restore", 
-					      GNOME_STOCK_PIXMAP_OPEN, 
-					      _("Restore..."), 
-					      restore_dialog, 
-					      NULL);	 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "restart", 
-					      GNOME_STOCK_PIXMAP_REFRESH, 
-					      _("Restart daemon"), 
-					      restart_cb, 
-					      NULL); 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "lastlog", 
-					      GNOME_STOCK_MENU_PREF, 
-					      _("Last sync log..."), 
-					      GTK_SIGNAL_FUNC (lastlog_dialog), 
-					      NULL);	 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "conduitprops", 
-					      GNOME_STOCK_MENU_PROP, 
-					      _("Conduit Settings..."), 
-					      GTK_SIGNAL_FUNC (pilot_link_dialog), 
-					      GINT_TO_POINTER (1));	 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "pilotlinkprops", 
-					      GNOME_STOCK_MENU_PROP, 
-					      _("Pilot Link Settings..."), 
-					      GTK_SIGNAL_FUNC (pilot_link_dialog), 
-					      NULL);	 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "properties", 
-					      GNOME_STOCK_MENU_PROP, 
-					      _("Properties..."), 
-					      GTK_SIGNAL_FUNC (properties_dialog), 
-					      NULL);	 
-#endif
+
 	/* Now set the dnd features */
 	gtk_drag_dest_set (GTK_WIDGET (self->pixmap), 
 			   GTK_DEST_DEFAULT_ALL, 
@@ -1290,28 +1308,6 @@ create_pilot_widgets (GtkWidget *widget, PilotApplet *self)
 	install_popup_menu (self, FALSE);
 }
 
-/* static GtkWidget * applet_start_new_applet (const gchar *goad_id, const char **params, int nparams) { */
-/* 	GtkWidget *pilot; */
-/* 	GtkWidget *applet; */
-  
-/* 	if (strcmp (goad_id, "gpilot-applet")) return NULL; */
-     
-/* 	applet = applet_widget_new (goad_id); */
-/* 	if (!applet) */
-/* 		g_error (_("Can't create applet!\n")); */
-  
-/* 	gtk_widget_realize (applet); */
-/* 	pilot = create_pilot_widget (applet); */
-/* 	gtk_widget_show_all (pilot); */
-
-
-/* 	applet_widget_add (APPLET_WIDGET (applet), pilot); */
-/* 	gtk_widget_show (applet); */
-  
-/* 	return applet; */
-/* } */
-
-
 static gboolean
 pilot_applet_fill (PanelApplet *applet)
 {
@@ -1406,7 +1402,7 @@ pilot_applet_factory ( PanelApplet *applet,
 }
 PANEL_APPLET_BONOBO_FACTORY( "OAFIID:GNOME_PilotApplet_Factory",
 			     PANEL_TYPE_APPLET,
-			     "Pilot-Applet",
+			     "gnome-pilot",
 			     "0",
 			     (PanelAppletFactoryCallback) pilot_applet_factory,
 			     NULL)
