@@ -93,6 +93,7 @@ static void fill_widgets (GnomePilotDruid *gpd);
 
 static gboolean gpd_delete_window (GtkWidget *widget,GdkEvent *event,gpointer user_data);
 static void gpd_canceled (GnomeDruid *druid, gpointer user_data);
+static void gpd_help (GnomeDruid *druid, gpointer user_data);
 
 static void gpd_cradle_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data);
 static void gpd_sync_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data);
@@ -180,6 +181,7 @@ init (GnomePilotDruid *gpd)
 	init_widgets (gpd);
 
  error:
+	;
 }
 
 
@@ -304,6 +306,9 @@ init_widgets (GnomePilotDruid *gpd)
 
 	gtk_signal_connect (GTK_OBJECT (priv->druid), "cancel",
 			    GTK_SIGNAL_FUNC (gpd_canceled), gpd);
+	gtk_signal_connect (GTK_OBJECT (priv->druid), "help",
+			    GTK_SIGNAL_FUNC (gpd_help), gpd);
+
 
 	/* Page signals */
 	g_signal_connect_after (G_OBJECT (priv->page_cradle), "prepare",
@@ -460,6 +465,12 @@ gpd_canceled (GnomeDruid *druid, gpointer user_data)
 		gtk_main_quit ();
 }
 
+static void 
+gpd_help (GnomeDruid *druid, gpointer user_data)
+{
+	gnome_help_display_desktop (NULL, "gnome-pilot", "gnome-pilot.xml", "assistant", NULL);
+}
+
 static void
 gpd_cradle_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data)
 {
@@ -467,7 +478,7 @@ gpd_cradle_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data
 	gboolean ready;
 	
 	ready = check_cradle_settings (gpd);
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (arg1), TRUE, ready, TRUE, FALSE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (arg1), TRUE, ready, TRUE, TRUE);
 }
 
 static void
@@ -529,7 +540,7 @@ gpd_sync_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data)
 	}
 
 	/* disable NEXT until we've synced */
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, FALSE, TRUE, FALSE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, FALSE, TRUE, TRUE);
 }
 
 static gboolean
@@ -587,7 +598,7 @@ gpd_device_info_check (GtkEditable *editable, gpointer user_data)
 	priv = gpd->priv;
 	
 	ready = check_cradle_settings (gpd);
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, FALSE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, TRUE);
 }
 
 static void
@@ -602,7 +613,7 @@ gpd_pilot_info_check (GtkEditable *editable, gpointer user_data)
 	if (GTK_TOGGLE_BUTTON (priv->pilot_info_no)->active)
 		ready = check_pilot_settings (gpd);
 
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, FALSE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, TRUE);
 }
 
 static void
@@ -618,7 +629,7 @@ gpd_pilot_info_button (GtkToggleButton *toggle, gpointer user_data)
 	if (toggle->active)
 		ready = check_pilot_settings (gpd);
 
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, FALSE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, TRUE);
 }
 
 static void 
@@ -632,7 +643,7 @@ gpd_request_completed (GnomePilotClient* client, const gchar *id, gint handle, g
 	if (handle != priv->handle)
 		return;
 	
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE, FALSE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE, TRUE);
 }
 
 static void 
@@ -665,7 +676,7 @@ gpd_userinfo_requested (GnomePilotClient *gpc, const gchar *device, const GNOME_
 	g_snprintf (buf, sizeof (buf), "%d", priv->pilot->pilot_id);
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_id), buf);
 
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE, FALSE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE, TRUE);
 
 	g_free (text);
 	priv->handle = -1;
