@@ -26,6 +26,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <pi-util.h>
 
 #include "pilot.h"
 
@@ -181,6 +182,7 @@ loadPilotPilot (PilotState *p)
   GPilotPilot *pilot;
   gboolean notfound;
   gchar *prefix;
+  char *local_name;
   int i, num;
 
   gnome_config_push_prefix ("/gnome-pilot.d/gpilotd/General/");
@@ -202,7 +204,11 @@ loadPilotPilot (PilotState *p)
 		  if (notfound)
 			  pilot->pilot_id = getuid ();
 		  g_message ("Pilot id   -> %d", pilot->pilot_id);
-		  pilot->pilot_username = gnome_config_get_string ("pilotusername");
+		  local_name = gnome_config_get_string ("pilotusername");
+		  if (!local_name || (convert_FromPilotChar ("UTF-8", local_name, strlen(local_name), &pilot->pilot_username) == -1)) {
+  		  	pilot->pilot_username = g_strdup (local_name);
+		  }
+		  g_free (local_name);
 		  g_message ("Pilot username -> %s", pilot->pilot_username);
 	  
 		  pilot->creation = gnome_config_get_int ("creation");
@@ -260,6 +266,7 @@ savePilotState (PilotState *state)
   int i;
   GList *tmp;
   gchar *prefix;
+  char *local_name;
 
   gnome_config_clean_section ("/gnome-pilot.d/gpilotd/General/");
 
@@ -310,7 +317,11 @@ savePilotState (PilotState *state)
 	  gnome_config_set_int ("pilotid", pilot->pilot_id);
 	  gnome_config_set_int ("creation", pilot->creation);
 	  gnome_config_set_int ("romversion", pilot->romversion);
-	  gnome_config_set_string ("pilotusername", pilot->pilot_username);
+	  if (!pilot->pilot_username|| (convert_ToPilotChar ("UTF-8", pilot->pilot_username, strlen (pilot->pilot_username),&local_name) == -1)) {
+		  local_name = g_strdup (pilot->pilot_username);
+	  }
+	  gnome_config_set_string ("pilotusername", local_name);
+	  g_free (local_name);
 	  gnome_config_set_string ("basedir", pilot->sync_options.basedir);
 	  gnome_config_pop_prefix ();
 	  g_free (prefix);
@@ -392,7 +403,7 @@ load_conduit_list (GPilotPilot *pilot)
 	return conduit_states;
 }
 
-void *
+void
 free_conduit_list (GList *conduits)
 {
 	/* FIXME Properly free each state */
